import Link from "next/link";
import Image from "next/image";

import { ChevronRight } from "lucide-react";

import { siteConfig } from "@/lib/config";
import { buttonVariants } from "../ui/button";
import { FaBook, FaDiscord } from "react-icons/fa";
import { FaXTwitter } from "react-icons/fa6";

const headerLinks = [
  {
    title: "Resources",
    links: [
      { href: "#", text: "FAQ", icon: null },
      { href: "#", text: "Documentation", icon: null },
      // { href: "#", text: "Pricing", icon: null },
      // { href: "#", text: "API", icon: null },
    ],
  },
];

export default function Footer() {
  return (
    <footer>
      <div className="layout py-16 sm:px-10 px-5">
        <div className="grid sm:grid-cols-3">
          <div>
            <Link
              href="/"
              title={siteConfig.name}
              className="mb-5 relative mr-6 flex items-center space-x-2"
            >
              <Image
                src="/logo.png"
                height={44}
                width={44}
                alt="logo"
                className="rounded-md shadow"
              />
              <span className="font-bold text-xl">{siteConfig.name}</span>
            </Link>
            <p className="mb-5">Build advanced custom ai agents with no code</p>
            <ul className="flex gap-3">
              <li>
                <Link
                  href="/"
                  className={buttonVariants({
                    variant: "outline",
                    size: "icon",
                  })}
                >
                  <FaBook className="text-primary" />
                </Link>
              </li>
              <li>
                <Link
                  href="/"
                  className={buttonVariants({
                    variant: "outline",
                    size: "icon",
                  })}
                >
                  <FaXTwitter className="text-primary" />
                </Link>
              </li>
              <li>
                <Link
                  href="/"
                  className={buttonVariants({
                    variant: "outline",
                    size: "icon",
                  })}
                >
                  <FaDiscord className="text-primary" />
                </Link>
              </li>
            </ul>
          </div>
          {headerLinks.map((section, index) => (
            <div key={index} className="mb-5">
              <h2 className="font-semibold">{section.title}</h2>
              <ul>
                {section.links.map((link, linkIndex) => (
                  <li key={linkIndex} className="my-2">
                    <Link
                      href={link.href}
                      className="group inline-flex cursor-pointer items-center justify-start gap-1 text-muted-foreground duration-200 hover:text-foreground hover:opacity-90"
                    >
                      {link.icon && link.icon}
                      {link.text}
                      <ChevronRight className="h-4 w-4 translate-x-0 transform opacity-0 transition-all duration-300 ease-out group-hover:translate-x-1 group-hover:opacity-100" />
                    </Link>
                  </li>
                ))}
              </ul>
            </div>
          ))}
        </div>
      </div>
    </footer>
  );
}
